@@ -11,10 +11,12 @@ if PAGSEGURO_SANDBOX:
     CHECKOUT_URL = 'https://ws.sandbox.pagseguro.uol.com.br/v2/checkout'
     PAYMENT_URL = 'https://sandbox.pagseguro.uol.com.br/v2/checkout/payment.html'
     NOTIFICATION_URL = 'https://ws.sandbox.pagseguro.uol.com.br/v2/transactions/notifications'
+    TRANSACTION_URL = 'https://ws.sandbox.pagseguro.uol.com.br/v2/transactions'
 else:
     CHECKOUT_URL = 'https://ws.pagseguro.uol.com.br/v2/checkout'
     PAYMENT_URL = 'https://pagseguro.uol.com.br/v2/checkout/payment.html'
     NOTIFICATION_URL = 'https://ws.pagseguro.uol.com.br/v2/transactions/notifications'
+    TRANSACTION_URL = 'https://ws.pagseguro.uol.com.br/v2/transactions'
 
 TRANSACTION_STATUS = {
     '1': 'aguardando',
