@@ -1,4 +1,4 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 from django.test import TestCase
 
 from decimal import Decimal
@@ -6,7 +6,9 @@ import httpretty
 from dateutil.parser import parse
 
 from pagseguro.api import PagSeguroItem, PagSeguroApi
-from pagseguro.settings import CHECKOUT_URL, PAYMENT_URL, NOTIFICATION_URL
+from pagseguro.settings import (
+    CHECKOUT_URL, PAYMENT_URL, NOTIFICATION_URL, TRANSACTION_URL
+)
 
 
 class PagSeguroItemTest(TestCase):
@@ -19,27 +21,39 @@ class PagSeguroItemTest(TestCase):
             'quantity': 1
         }
 
-    def test_invalid_item(self):
+    def test_invalid_amount(self):
         self.data['amount'] = 'invalid'
         self.assertRaises(Exception, lambda: PagSeguroItem(**self.data))
 
-        self.data['amount'] = '10.00'
+        self.data['amount'] = '10.0'
+        self.assertRaises(Exception, lambda: PagSeguroItem(**self.data))
+
+        self.data['amount'] = '10.000'
+        self.assertRaises(Exception, lambda: PagSeguroItem(**self.data))
+
+    def test_invalid_quantity(self):
         self.data['quantity'] = 'ten'
         self.assertRaises(Exception, lambda: PagSeguroItem(**self.data))
 
-        self.data['quantity'] = 1
+    def test_invalid_id(self):
         self.data['id'] = '0' * 101
         self.assertRaises(Exception, lambda: PagSeguroItem(**self.data))
 
-        self.data['id'] = '0001'
+    def test_invalid_description(self):
         self.data['description'] = 'a' * 101
         self.assertRaises(Exception, lambda: PagSeguroItem(**self.data))
 
-        self.data['description'] = 'My item 1'
+    def test_invalid_shipping_cost(self):
         self.data['shipping_cost'] = 'invalid'
         self.assertRaises(Exception, lambda: PagSeguroItem(**self.data))
 
-        self.data['shipping_cost'] = '10.00'
+        self.data['shipping_cost'] = '10.0'
+        self.assertRaises(Exception, lambda: PagSeguroItem(**self.data))
+
+        self.data['shipping_cost'] = '10.000'
+        self.assertRaises(Exception, lambda: PagSeguroItem(**self.data))
+
+    def test_invalid_weight(self):
         self.data['weight'] = 'ten'
         self.assertRaises(Exception, lambda: PagSeguroItem(**self.data))
 
@@ -117,6 +131,63 @@ notification_response_xml = '''<?xml version="1.0" encoding="UTF-8"?>
   </shipping>
 </transaction>'''
 
+transaction_response_xml = '''<?xml version="1.0" encoding="ISO-8859-1" standalone="yes"?>
+<transaction>
+    <date>2011-02-05T15:46:12.000-02:00</date>
+    <lastEventDate>2011-02-15T17:39:14.000-03:00</lastEventDate>
+    <code>9E884542-81B3-4419-9A75-BCC6FB495EF1</code>
+    <reference>REF1234</reference>
+    <type>1</type>
+    <status>3</status>
+    <paymentMethod>
+        <type>1</type>
+        <code>101</code>
+    </paymentMethod>
+    <grossAmount>49900.00</grossAmount>
+    <discountAmount>0.00</discountAmount>
+    <feeAmount>0.00</feeAmount>
+    <netAmount>49900.50</netAmount>
+    <extraAmount>0.00</extraAmount>
+    <installmentCount>1</installmentCount>
+    <itemCount>2</itemCount>
+    <items>
+        <item>
+            <id>0001</id>
+            <description>Notebook Prata</description>
+            <quantity>1</quantity>
+            <amount>24300.00</amount>
+        </item>
+        <item>
+            <id>0002</id>
+            <description>Notebook Rosa</description>
+            <quantity>1</quantity>
+            <amount>25600.00</amount>
+        </item>
+    </items>
+    <sender>
+        <name>José Comprador</name>
+        <email>comprador@uol.com.br</email>
+        <phone>
+            <areaCode>11</areaCode>
+            <number>56273440</number>
+        </phone>
+    </sender>
+    <shipping>
+        <address>
+            <street>Av. Brig. Faria Lima</street>
+            <number>1384</number>
+            <complement>5o andar</complement>
+            <district>Jardim Paulistano</district>
+            <postalCode>01452002</postalCode>
+            <city>Sao Paulo</city>
+            <state>SP</state>
+            <country>BRA</country>
+        </address>
+        <type>1</type>
+        <cost>21.50</cost>
+    </shipping>
+</transaction>'''
+
 checkout_response_xml = '''<?xml version="1.0" encoding="UTF-8"?>
 <checkout>
   <code>67DB59D3BDBD84EAA4396F929DB350A7</code>
@@ -248,3 +319,42 @@ class PagSeguroApiTest(TestCase):
             'A5182C-C9EF48EF48D2-1FF4AF6FAC82-EB2948'
         )
         self.assertEqual(response.status_code, 200)
+
+    @httpretty.activate
+    def test_get_invalid_transaction(self):
+        # mock requests
+        httpretty.register_uri(
+            httpretty.GET,
+            TRANSACTION_URL + '/{0}'.format(
+                '9E884542-81B3-4419-9A75-BCC6FB495EF1'
+            ),
+            body='Unauthorized',
+            status=401,
+        )
+
+        data = self.pagseguro_api.get_transaction(
+            '9E884542-81B3-4419-9A75-BCC6FB495EF1'
+        )
+        self.assertEqual(data['status_code'], 401)
+        self.assertEqual(data['message'], 'Unauthorized')
+
+    @httpretty.activate
+    def test_get_valid_transaction(self):
+        # mock requests
+        httpretty.register_uri(
+            httpretty.GET,
+            TRANSACTION_URL + '/{0}'.format(
+                '9E884542-81B3-4419-9A75-BCC6FB495EF1'
+            ),
+            body=transaction_response_xml,
+            status=200,
+        )
+
+        data = self.pagseguro_api.get_transaction(
+            '9E884542-81B3-4419-9A75-BCC6FB495EF1'
+        )
+        self.assertEqual(data['status_code'], 200)
+        self.assertEqual(
+            data['transaction']['code'],
+            '9E884542-81B3-4419-9A75-BCC6FB495EF1'
+        )
